{% include "django/forms/widgets/input.html" %}
<label style="background: {{ widget.label }}" {% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %}></label>
<div style="text-align: center;"><small>{{ widget.label }}</small></div>